@@ -1,8 +1,8 @@
 # This file will be patched by setup.py
 # The __version__ should be set to the branch name
-# (e.g. "trunk" or "0.4.x")
+# (e.g. "develop" or "1.2.x")
 
 # You MUST use double quotes (so " and not ')
 
-__version__ = "1.0.3"
-__baseline__ = "927ba3cd9d330a74fbdfc8d926f9cbc6aee764af"
+__version__ = "2.3.9"
+__baseline__ = "03c10dce91e13918bc2e6f8ca9c309196b90be11"
